@@ -33,7 +33,7 @@ _LOG_CONNECTION = os.environ.get('KOMBU_LOG_CONNECTION', False)
 _LOG_CHANNEL = os.environ.get('KOMBU_LOG_CHANNEL', False)
 
 __all__ = ['Connection', 'ConnectionPool', 'ChannelPool']
-URI_PASSTHROUGH = frozenset(['sqla', 'sqlalchemy'])
+URI_PASSTHROUGH = frozenset(['sqla', 'sqlalchemy', 'zeromq', 'zmq'])
 
 logger = get_logger(__name__)
 
@@ -657,7 +657,7 @@ class Connection(object):
 
     @property
     def is_evented(self):
-        return getattr(self.transport, 'on_poll_start', None)
+        return self.transport.supports_ev
 BrokerConnection = Connection
 
 
