@@ -71,6 +71,8 @@ TRANSPORT_ALIASES = {
     'ghettoq.taproot.Beanstalk': _ghettoq('Beanstalk', 'beanstalk'),
     'ghettoq.taproot.CouchDB': _ghettoq('CouchDB', 'couchdb'),
     'filesystem': 'kombu.transport.filesystem.Transport',
+    'zeromq': 'kombu.transport.zmq.Transport',
+    'zmq': 'kombu.transport.zmq.Transport',
 }
 
 _transport_cache = {}
